from tkinter import Tk, VERTICAL, LEFT, RIGHT, Y, BOTH
from tkinter import ttk

from instance import Instance, gen_function_for_instance
from settings import MainSettings, SortType


def start_ui(instances: [Instance], settings):
    root = Tk()

    # Alphanumeric sorting
    if MainSettings.Sort == SortType.ALPHA:
        instances = list(sorted(instances))

    canvas = ttk.Canvas(root)
    scrollbar = ttk.Scrollbar(root, orient=VERTICAL, command=canvas.yview)
    frame = ttk.Frame(canvas)

    frame.bind(
        "<Configure>",
        lambda e: canvas.configure(
            scrollregion=canvas.bbox("all")
        )
    )

    canvas.create_window((0, 0), window=frame, anchor="nw")
    canvas.configure(yscrollcommand=scrollbar.set)

    canvas.pack(side=LEFT, fill=BOTH, expand=True)
    scrollbar.pack(side=RIGHT, fill=Y)

    ttk.Label(frame, text="Available Databases").grid(column=0, row=0)

    for row, instance in enumerate(instances):
        if instance.disable and not MainSettings.ShowAll:
            continue
        ttk.Button(frame,
                   text=instance.name,
                   command=gen_function_for_instance(instance)).grid(column=0,
                                                                     row=row+1)

    root.mainloop()
